#define DEBUG 0
#include <Debug.h>

#include <stdio.h>
#include <string.h>

#include "URL_App.h"

int main(void)
{
	new URL_App ();
	be_app	-> Run();
	delete	be_app;
	return (0);
}

URL_App::URL_App	(void)
 : BApplication	("application/x-vnd.Be-URLH")
{
	m_settings_file 		=	new BFile();
	m_url_window			=	NULL;

	status_t  status		=	B_OK;
				
	status = CreateSettingsFile();
	if (status != B_OK)	
		PrintErrorMessage("CreateSettingsFile()", status);
			// we can continue without it
	
	InstallTypesIfMissing();
}

URL_App::~URL_App	(void)	
{
	// void
}

void
URL_App::ReadyToRun	(void)
{
	m_url_window = new URL_Window(m_settings_file);
	m_url_window->Show();
	m_url_window->Lock();
	m_url_window->PostMessage('init');
	m_url_window->Unlock();
}

void 
URL_App::MessageReceived	(BMessage * a_message)
{
	switch(a_message->what)
	{
		case 'help':									// open Documentation
				// Help();
				break;
		
		default:
				BApplication::MessageReceived(a_message);
				break;			
	}
}

void
URL_App::AboutRequested	(void)
{
	BAlert * alert = new BAlert("About URL Preferences", 
			"URL Handlers\n\n"
			"A preference application for OBOS.\n"
			"Originated by Jonas Sundström.\n", "Nice",
			NULL, NULL, B_WIDTH_AS_USUAL, B_INFO_ALERT);

	alert->Go(NULL);
}

void
URL_App::PrintErrorMessage	(const char * a_text, int32 a_status)
{
	PRINT(("%s: %s\n", a_text, strerror(a_status)));
}

status_t
URL_App::CreateSettingsFile	(void)
{
	status_t status;
	BPath path;

	status = find_directory(B_USER_SETTINGS_DIRECTORY, &path);
	if (status != B_OK)
		return status;

	status = path.SetTo(path.Path(),"URL_Handlers.bmsg");
	if (status != B_OK)
		return status;

	status =	m_settings_file->	SetTo(path.Path(),	B_READ_WRITE | B_CREATE_FILE);
	if (status == B_OK || status == B_FILE_EXISTS)	return B_OK;
		else											return status;
}

void 
URL_App::InstallTypesIfMissing	(void)
{
	BMimeType	mime;
	
	mime.SetTo("application/x-vnd.Be.URL.file");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The file URL scheme is used to designate files "
								"accessible locally on your own computer.");
		mime.Install();
	}
	
	mime.SetTo("application/x-vnd.Be.URL.ftp");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The File Transfer Protocol. FTP links point to FTP servers.");
		mime.Install();
	}

	mime.SetTo("application/x-vnd.Be.URL.http");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The HyperText Transfer Protocol. HTTP links point to webservers.");
		mime.Install();
	}

	mime.SetTo("application/x-vnd.Be.URL.https");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The Secure HyperText Transfer Protocol. HTTPS links point to secure webpages.");
		mime.Install();
	}

	mime.SetTo("application/x-vnd.Be.URL.rtsp");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The Real-Time Streaming Protocol. RTSP links point to media-streaming servers.");
		mime.Install();
	}
			
	mime.SetTo("application/x-vnd.Be.URL.telnet");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("The Telnet Protocol. Telnet links point to Telnet servers.");
		mime.Install();
	}
		
	mime.SetTo("application/x-vnd.Be.URL.mailto");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("Mailto links make the browser launch an application "
								"to send an email to the emailaddress in the link.");
		mime.Install();
	}
	
	mime.SetTo("application/x-vnd.Be.URL.beshare");	
	if (! mime.IsInstalled())
	{
		mime.SetLongDescription("BeShare links point to MUSCLE servers, "
								"frequently visited by BeShare chat & filesharing clients.");
		mime.Install();
	}
}

